package com.emato.cuspay.web.controller.wx;

import com.emato.cuspay.dto.wx.WxCbPayDoc;
import com.emato.cuspay.service.wx.CusPayService;
import com.emato.cuspay.support.msg.resp.ResponseMessage;
import com.emato.cuspay.support.msg.resp.ResponseStatus;
import com.emato.cuspay.util.MapBeanUtils;
import com.emato.cuspay.util.Validator;
import com.emato.cuspay.util.jackson.JacksonUtil;
import com.google.common.base.Strings;
import com.google.common.collect.Maps;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/**
 * @author zx
 * @version 1.0
 * 2018-05-15 09:31
 */

@RestController
@RequestMapping("/wx/custom")
public class WxCusController {
    private static final Logger logger = LoggerFactory.getLogger(WxCusController.class);

    @Autowired
    private CusPayService customService;

    /**
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/declarepayment")
    public ResponseMessage declarePayment(HttpServletRequest request){
        String sn = request.getParameter("sn");
        String name = request.getParameter("name");
        System.out.println("============"+sn +":"+ name);
        return new ResponseMessage.Builder().setCode(ResponseStatus.SUCCESS.getItem()).setMsg("ok").build();
    }

    /**
     * 支付单信息入库接口
     * @param request
     * @return
     */
    @RequestMapping(value = "/wxcbpay", method = RequestMethod.POST)
    public ResponseMessage addWxCbPayDoc(HttpServletRequest request) {
        logger.info("支付单信息入库接口请求开始");
        String result = request.getParameter("result");
        // 检查参数是否齐全
        if (Strings.isNullOrEmpty(result)) {
            return  new ResponseMessage.Builder().setCode(ResponseStatus.ERROR.getItem()).setMsg("缺少业务数据").build();
        }
        logger.info("支付单信息入库接口请求数据:【{}】",result);

        //解析数据
        WxCbPayDoc wxCbPayDoc = JacksonUtil.fromStringJson(result, WxCbPayDoc.class);
        //数据校验
        Map<String, Object> validate = MapBeanUtils.fromObject(wxCbPayDoc);
        Map<String, Object> beVerified = Maps.newHashMap();

        beVerified.put("merchSn", "商户编号");
        beVerified.put("merchName", "商户名称");
        beVerified.put("platSn","平台编号");
        beVerified.put("platName","平台中文名称");
        beVerified.put("appid", "微信公众号ID");
        beVerified.put("mchId","微信支付商户号");
        beVerified.put("outTradeNo", "商户订单号");
        beVerified.put("transactionId","微信支付订单号");
        beVerified.put("customs","报送海关");
        beVerified.put("mchCustomsNo","商户海关备案号");

        ResponseMessage rst = Validator.isEmpty(beVerified, validate);
        if (ResponseStatus.ERROR.getItem().equals(rst.getCode())) {
            return  rst;
        }

        return customService.addWxCbPayDoc(wxCbPayDoc);
    }
}
